@@ -7,6 +7,7 @@ import os, sys, requests, ast, json, pathlib, glob, platform, subprocess, time,
 # inc imports.
 import cl1
 from fil3s import Files, Formats
+from r3sponse import r3sponse
 
 # fyunctions.
 def __get_operating_system__():
@@ -14,7 +15,7 @@ def __get_operating_system__():
 	if os in ["darwin"]: return "osx"
 	elif os in ["linux"]: return "linux"
 	else: raise ValueError(f"Unsupported operating system: [{os}].")
-def __get_source_path__(package_name, index=1):
+def __get_source_path__(package_name, back=1):
 	executive_dir = str(pathlib.Path(__file__).absolute()).replace(os.path.basename(pathlib.Path(__file__)), '').replace("//","/")
 	if executive_dir[len(executive_dir)-1] == "/": executive_dir = executive_dir[:-1]
 	source, c = "/", 1
@@ -64,7 +65,7 @@ def __check_alias__(
 # source.
 ALIAS = "syst3m"
 SOURCE_NAME = "syst3m"
-SOURCE_PATH= Formats.FilePath(__file__).base(back=3)
+SOURCE_PATH= __get_source_path__(__file__, back=3)
 OS = __get_operating_system__()
 
 # universal variables.
