@@ -3,7 +3,7 @@
 
 # imports.
 from syst3m.classes.config import *
-from syst3m.classes import utils
+from syst3m.classes import utils, console
 import platform 
 
 # kill pid.
@@ -17,11 +17,11 @@ def kill(
 ):
 	if loader:
 		log_level = 0
-		loader_ = syst3m.console.Loader(f"Killing process {pid}.")
+		loader_ = console.Loader(f"Killing process {pid}.")
 	else:
 		log_level = -1
 	_sudo_ = Formats.Boolean(sudo).convert(true="sudo ", false="")
-	output = syst3m.utils.__execute_script__(f"{_sudo_}kill {pid}")
+	output = utils.__execute_script__(f"{_sudo_}kill {pid}")
 	if "terminated" in output:
 		if loader: loader_.stop()
 		return r3sponse.success_response(f"Successfully killed process {pid}.")
@@ -38,20 +38,22 @@ def processes(
 ):
 	_sudo_ = Formats.Boolean(sudo).convert(true="sudo ", false="")
 	if isinstance(includes, str):
-		command = f"""{sudo}ps -ax | grep "{includes}" | """
+		command = f"""{_sudo_}ps -ax | grep "{includes}" | """
 	else:
-		command = f"""{sudo}ps -ax | """
-	output = syst3m.utils.__execute_script__(command + """awk '{print $1"|"$2"|"$3"|"$4}' """)
+		command = f"""{_sudo_}ps -ax | """
+	output = utils.__execute_script__(command + """awk '{print $1"|"$2"|"$3"|"$4}' """)
 	processes = {}
 	for line in output.split("\n"):
 		if line not in ["", " "]:
-			pid,tty,_,process = line.split("|")
+			try:
+				pid,tty,_,process = line.split("|")
+			except ValueError: raise ValueError(f"Unable to unpack process line: [{line}], expected format: [4] seperator: [|].")
 			processes[pid] = {
 				"pid":pid,
 				"tty":tty,
 				"process":process,
 			}
-	return r3sponse.sucess_response(f"Successfully listed {len(processes)} processes.", {
+	return r3sponse.success_response(f"Successfully listed {len(processes)} processes.", {
 		"processes":processes,
 	})
 
